@@ -3,12 +3,12 @@ function(FILEPATH,ATESTS,MEASURES,LARGEDIFFINDICATOR,GRAPHOUTPUTNAME,TIMEPOINT,T
 {
 	# Where the A-Test Results are - at present spartan only outputs test results as CSV
 	#ATESTS <- read.csv(paste(FILEPATH,"/",SAMPLESIZE,"/",ATESTRESULTSFILENAME,".csv",sep=""),header=TRUE)
-	ATESTS<-data.frame(ATESTS)
+	ATESTS<-data.frame(ATESTS,check.names = FALSE)
 
 	# Where the resulting graph should go
 	GRAPHFILE = paste(FILEPATH,"/",GRAPHOUTPUTNAME,sep="")
-	pdf(GRAPHFILE,width=12,height=7)
-	par(xpd=NA,oma=c(0,0,0,14))
+	pdf(GRAPHFILE, width=12, height=7)
+	par(xpd=NA,mar=c(4,4,4,17))
 
 	# WILL PLOT EACH MEASURE IN TURN.  BUT PLOT THE INITIAL MEASURE FIRST
 	MEASURELABEL<-paste("ATest",MEASURES[1],sep="")
@@ -39,7 +39,7 @@ function(FILEPATH,ATESTS,MEASURES,LARGEDIFFINDICATOR,GRAPHOUTPUTNAME,TIMEPOINT,T
 	}
 
 	axis(1,at=seq(2,nrow(ATESTS)+1,by=2))
-	legend(par("usr")[2],par("usr")[4],title="MEASURES",MEASURES,pch=1:length(MEASURES),lty=1,xjust=0,yjust=2.0)
+	legend(par("usr")[2],par("usr")[4],title="MEASURES",MEASURES, pch=1:length(MEASURES),cex=0.7,ncol=1)
 	par(xpd=FALSE)
 
 	# ADD THE SIGNIFICANCE LINES
