@@ -6,8 +6,9 @@ function(FILEPATH,EFASTSAMPLE_RESULTFILENAME,PARAMETERS,NUMCURVES,NUMSAMPLES,MEA
 	
 	# BUT FIRST, WE MAY NEED TO CHANGE THE PARAMETER AND MEASURE STRINGS. WHEN R IMPORTS THE SPREADSHEET, ANY HYPHENS OR SPACES ARE CHANGED
 	# TO DOTS, AND THIS NEEDS DETECTING
-	PARAMETERS<-table_header_check(PARAMETERS)
-	MEASURES<-table_header_check(MEASURES)
+	# April 2015 - do not need to do this anymore, using check.names=FALSE when reading CSVs
+	#PARAMETERS<-table_header_check(PARAMETERS)
+	#MEASURES<-table_header_check(MEASURES)
 
 
 	for(CURVENUM in 1:NUMCURVES)
@@ -17,7 +18,7 @@ function(FILEPATH,EFASTSAMPLE_RESULTFILENAME,PARAMETERS,NUMCURVES,NUMSAMPLES,MEA
 
 			print(paste("Processing Curve: ",CURVENUM," Parameter: ",PARAMETERS[PARAMNUM],sep="")) 
 			# Open the parameter file
-			params<-read.csv(paste(FILEPATH,"/Curve",CURVENUM,"_",PARAMETERS[PARAMNUM],".csv",sep=""))
+			params<-read.csv(paste(FILEPATH,"/Curve",CURVENUM,"_",PARAMETERS[PARAMNUM],".csv",sep=""),header=TRUE,check.names=FALSE)
 
 			CURVE_PARAM_RESULT<-NULL
 
@@ -29,7 +30,7 @@ function(FILEPATH,EFASTSAMPLE_RESULTFILENAME,PARAMETERS,NUMCURVES,NUMSAMPLES,MEA
 
 					# READ IN THE RESULT FILE
 					# SKIP THE FIRST 6 LINES AS NONE OF THIS INFORMATION IS REQUIRED
-					NL_RESULT<-read.csv(paste(FILEPATH,"/",CURVENUM,"/",PARAMNUM,"/",SAMPLE,"/",EFASTSAMPLE_RESULTFILENAME,SAMPLE,".csv",sep=""),sep=",",skip=6)
+					NL_RESULT<-read.csv(paste(FILEPATH,"/",CURVENUM,"/",PARAMNUM,"/",SAMPLE,"/",EFASTSAMPLE_RESULTFILENAME,SAMPLE,".csv",sep=""),sep=",",skip=6,check.names=FALSE)
 
 					# ORDER IT BY RUN FOR EFFICIENCY LATER
 					NL_RESULT_ORDERED<-NL_RESULT[order(NL_RESULT[,1]),]
@@ -37,8 +38,10 @@ function(FILEPATH,EFASTSAMPLE_RESULTFILENAME,PARAMETERS,NUMCURVES,NUMSAMPLES,MEA
 					# REMOVE ALL THE OTHER TIMESTEPS AS NOT REQUIRED
 					# THE TIMESTEP IS IN THE COLUMN HEADED X.step.
 					# SET THIS TO NULL TO PLEASE CRAN SUBMISSION NOTE, THEN SUBSET
-					X.step.<-NULL
-					TIMESTEP_RESULTS<-subset(NL_RESULT_ORDERED,X.step.==TIMESTEP)
+					# KA: REMOVED THIS APRIL 2015
+					#X.step.<-NULL
+					#TIMESTEP_RESULTS<-subset(NL_RESULT_ORDERED,X.step.==TIMESTEP)
+					TIMESTEP_RESULTS<-subset(NL_RESULT_ORDERED,NL_RESULT_ORDERED["[step]"]==TIMESTEP)
 
 					# NOW TO CREATE THE RESULTS FOR THIS SAMPLE SET
 					# NETLOGO DOES GIVE THE OPTION OF RUNNING REPLICATES OF THE SAME EXPERIMENT
