@@ -12,14 +12,15 @@ function(FILEPATH,PARAMETERS,MEASURES,LHC_ALL_SIM_RESULTS_FILE,LHCSUMMARYFILENAM
 			# READ IN THE LHC DESIGN TABLE - NEED TO REFER TO THIS LATER AS PARAMETERS ARE LISTED WITH THE MEDIAN RESULT SET
 			print("Generating LHC result summary file from median simulation results (lhc_generateLHCSummary)")
 
+			# Not needed anymore, as using check.names=FALSE when reading CSV files
 			# Check the Measures and Parameters for Spaces - R will have replaced these with a dot
-			MEASURES<-table_header_check(MEASURES)
+			#MEASURES<-table_header_check(MEASURES)
 			
 			# SUMMARY TABLE WILL STORE THE PARAMETERS USED IN THE RUN SET, AND THE MEDIAN OUTPUT MEASURES, FOR EACH SET	
 			SUMMARYTABLE<-NULL
 
 			# READ IN THE RESULT FILE - EITHER PROVIDED OR CONSTRUCTED BY THE FIRST LHC METHOD IN SPARTAN
-			LHC_ALL_SIM_RESULTS<-read.csv(paste(FILEPATH,"/",LHC_ALL_SIM_RESULTS_FILE,sep=""),header=TRUE)
+			LHC_ALL_SIM_RESULTS<-read.csv(paste(FILEPATH,"/",LHC_ALL_SIM_RESULTS_FILE,sep=""),header=TRUE,check.names=FALSE)
 	
 			# NOW WE ARE PROCESSING A FILE WITH MULTIPLE RUNS OF THE SAME PARAMETER SET. TO SAVE IMPORTING THE PARAMETER FILE
 			# (AS THIS MAY NOT ALWAYS BE AVAILABLE), THIS READS THE PARAMETERS IN. THUS WE PUT A CHECK IN TO MAKE SURE WE DO
