@@ -74,7 +74,7 @@ function(FILEPATH,PARAMETERS,MEASURES,LHCSUMMARYFILENAME,CORCOEFFSOUTPUTFILE,TIM
 		for(n in 1:length(TIMEPOINTS))
 		{
 			TIMEPOINTPROCESSING<-TIMEPOINTS[n]
-			print(paste("PROCESSING TIMEPOINT: ",TIMEPOINTPROCESSING,sep=""))
+			print(paste("Processing Timepoint: ",TIMEPOINTPROCESSING,sep=""))
 
 			LHCSUMMARYFILENAME_FORMAT<-substr(LHCSUMMARYFILENAME,(nchar(LHCSUMMARYFILENAME)+1)-3,nchar(LHCSUMMARYFILENAME))
 			LHCSUMMARYFILENAME_FULL<-paste(substr(LHCSUMMARYFILENAME,0,nchar(LHCSUMMARYFILENAME)-4),"_",TIMEPOINTPROCESSING,".",LHCSUMMARYFILENAME_FORMAT,sep="")
