@@ -1,13 +1,14 @@
 lhc_process_netlogo_result <-
 function(FILEPATH,LHCSAMPLE_RESULTFILENAME,SPARTAN_PARAMETER_FILE,NUMSAMPLES,MEASURES,LHC_ALL_SIM_RESULTS_FILE,TIMESTEP)
 {
+	# Not using this anymore, as we're using check.names=FALSE when reading CSV files
 	# FIRST, WE MAY NEED TO CHANGE THE PARAMETER AND MEASURE STRINGS. WHEN R IMPORTS THE SPREADSHEET, ANY HYPHENS ARE CHANGED
 	# TO DOTS, AND THIS NEEDS DETECTING
-	PARAMETERS<-table_header_check(PARAMETERS)
-	MEASURES<-table_header_check(MEASURES)
+	#PARAMETERS<-table_header_check(PARAMETERS)
+	#MEASURES<-table_header_check(MEASURES)
 
 	# READ IN THE SPARTAN PARAMETER FILE
-	LHCTABLE<-read.csv(paste(FILEPATH,"/",SPARTAN_PARAMETER_FILE,sep=""),header=TRUE)
+	LHCTABLE<-read.csv(paste(FILEPATH,"/",SPARTAN_PARAMETER_FILE,sep=""),header=TRUE,check.names=FALSE)
 
 	# NOW ALL THE MEDIANS ARE HELD TOGETHER, ACCOMPANIED BY THEIR SIMULATION PARAMETERS BEING ANALYSED
 	ALL_SIM_MEDIAN_RESULTS<-NULL
@@ -20,7 +21,7 @@ function(FILEPATH,LHCSAMPLE_RESULTFILENAME,SPARTAN_PARAMETER_FILE,NUMSAMPLES,MEA
 
 			# READ IN THE RESULT FILE
 			# SKIP THE FIRST 6 LINES AS NONE OF THIS INFORMATION IS REQUIRED
-			NL_RESULT<-read.csv(paste(FILEPATH,"/",SAMPLE,"/",LHCSAMPLE_RESULTFILENAME,SAMPLE,".csv",sep=""),sep=",",skip=6)
+			NL_RESULT<-read.csv(paste(FILEPATH,"/",SAMPLE,"/",LHCSAMPLE_RESULTFILENAME,SAMPLE,".csv",sep=""),sep=",",skip=6,check.names=FALSE)
 
 			# ORDER IT BY RUN FOR EFFICIENCY LATER
 			NL_RESULT_ORDERED<-NL_RESULT[order(NL_RESULT[,1]),]
@@ -28,8 +29,10 @@ function(FILEPATH,LHCSAMPLE_RESULTFILENAME,SPARTAN_PARAMETER_FILE,NUMSAMPLES,MEA
 			# REMOVE ALL THE OTHER TIMESTEPS AS NOT REQUIRED
 			# THE TIMESTEP IS IN THE COLUMN HEADED X.step.
 			# SET THIS TO NULL TO PLEASE CRAN SUBMISSION NOTE, THEN SUBSET
-			X.step.<-NULL
-			TIMESTEP_RESULTS<-subset(NL_RESULT_ORDERED,X.step.==TIMESTEP)
+			#X.step.<-NULL
+			#TIMESTEP_RESULTS<-subset(NL_RESULT_ORDERED,X.step.==TIMESTEP)
+			# KA REMOVED APRIL 2015
+			TIMESTEP_RESULTS<-subset(NL_RESULT_ORDERED,NL_RESULT_ORDERED["[step]"]==TIMESTEP)
 
 			# NOW TO CREATE THE RESULTS FOR THIS SAMPLE SET
 			# NETLOGO DOES GIVE THE OPTION OF RUNNING REPLICATES OF THE SAME EXPERIMENT
@@ -67,7 +70,7 @@ function(FILEPATH,LHCSAMPLE_RESULTFILENAME,SPARTAN_PARAMETER_FILE,NUMSAMPLES,MEA
 		}
 	}
 	# NOW OUTPUT ALL THE MEDIAN RESULTS TO THE SPECIFIED FILEPATH
-	colnames(ALL_SIM_MEDIAN_RESULTS)<-cbind(t(PARAMETERS),t(MEASURES))
+	colnames(ALL_SIM_MEDIAN_RESULTS)<-cbind(t(names(LHCTABLE)),t(MEASURES))
 
 	# OUTPUT IF THE RESULTS ARE NOT BLANK
 	if(!is.null(ALL_SIM_MEDIAN_RESULTS))
