@@ -4,12 +4,13 @@ function(FILEPATH,NETLOGO_BEHAVIOURSPACEFILE,PARAMETERS,BASELINE,PMIN,PMAX,PINC,
 	# NOTE THAT ALTHOUGH NETLOGO FILE CONTAINS EACH PARAMETER FOR THE TURTLE, THE INPUT HERE ONLY NEEDS TO BE THE
 	# PARAMETERS THAT HAVE BEEN PERTURBED
 
+	# No longer in use, as have changed method of reading in CSV files (check.names=FALSE)
 	# Check the parameter and measures strings
-	PARAMETERS<-table_header_check(PARAMETERS)
-	MEASURES<-table_header_check(MEASURES)
+	#PARAMETERS<-table_header_check(PARAMETERS)
+	#MEASURES<-table_header_check(MEASURES)
 
 	## FIRSTLY READ IN THE NETLOGO RESULT FILE
-	NL_RESULT<-read.csv(paste(FILEPATH,"/",NETLOGO_BEHAVIOURSPACEFILE,sep=""),sep=",",skip=6)
+	NL_RESULT<-read.csv(paste(FILEPATH,"/",NETLOGO_BEHAVIOURSPACEFILE,sep=""),sep=",",skip=6, check.names=FALSE)
 
 	# ORDER IT BY RUN FOR EFFICIENCY LATER
 	NL_RESULT_ORDERED<-NL_RESULT[order(NL_RESULT[,1]),]
@@ -17,8 +18,10 @@ function(FILEPATH,NETLOGO_BEHAVIOURSPACEFILE,PARAMETERS,BASELINE,PMIN,PMAX,PINC,
 	# REMOVE ALL THE OTHER TIMESTEPS AS NOT REQUIRED
 	# THE TIMESTEP IS IN THE COLUMN HEADED X.step.
 	# SET THIS TO NULL TO PLEASE CRAN SUBMISSION NOTE, THEN SUBSET
-	X.step.<-NULL
-	TIMESTEP_RESULTS<-subset(NL_RESULT_ORDERED,X.step.==TIMESTEP)
+	# KA: REMOVED THIS APRIL 2015
+	#X.step.<-NULL
+	#TIMESTEP_RESULTS<-subset(NL_RESULT_ORDERED,X.step.==TIMESTEP)
+	TIMESTEP_RESULTS<-subset(NL_RESULT_ORDERED,NL_RESULT_ORDERED["[step]"]==TIMESTEP)
 
 	write.csv(TIMESTEP_RESULTS,paste(FILEPATH,"/",RESULTFILENAME,sep=""),quote = FALSE,row.names=FALSE)
 
